@@ -52,12 +52,11 @@ def _html_page_context(
 
 def setup(app):
     current_dir = os.path.abspath(os.path.dirname(__file__))
-    app.add_html_theme(
-        'python_docs_theme', current_dir)
+    app.add_html_theme("python_docs_theme", current_dir)
 
     app.connect("html-page-context", _html_page_context)
 
     return {
-        'parallel_read_safe': True,
-        'parallel_write_safe': True,
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
     }
